import ephem
from datetime import datetime, timedelta

def krc_easter(year):
    # 1. Frühlingsanfang berechnen (Exaktes Äquinoktium für Nordhalbkugel)
    equinox = ephem.next_equinox(f'{year}/3/19')  # meist 19.–21. März

    # 2. Nächsten Vollmond nach dem Frühlingspunkt berechnen
    full_moon = ephem.next_full_moon(equinox)

    # 3. Auf nächsten Sonntag runden (0=Mo ... 6=So)
    full_moon_dt = ephem.localtime(full_moon)
    weekday = full_moon_dt.weekday()
    days_until_sunday = (6 - weekday) % 7

    easter_dt = full_moon_dt + timedelta(days=days_until_sunday)

    return easter_dt.strftime('%Y-%m-%d'), full_moon_dt.strftime('%Y-%m-%d')

# Beispiel:
easter, full_moon = krc_easter(2025)
print(f"KRC-Ostern 2025: {easter} (Vollmond: {full_moon})")
